@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.140000';
+$BalanceOfPower::Commands::VERSION = '0.150000';
 use v5.10;
 use Moo;
 use IO::Prompter;
@@ -190,6 +190,8 @@ say <supports> for military supports
 
 say <rebel supports> for rebel military supports
 
+say <influences> for influences
+
 say <distance NATION1-NATION2> for distance between nations
 
 say <turn> to elaborate events for a new turn
@@ -252,6 +254,11 @@ COMMANDS
         print $self->world->print_allies();
         $result = { status => 1 };
     }
+    elsif($query eq "influences")
+    {
+        print $self->world->print_influences();
+        $result = { status => 1 };
+    }
     elsif($query eq "hotspots")
     {
         print $self->world->print_hotspots();
@@ -262,7 +269,11 @@ COMMANDS
         print $self->world->print_war_history();
         $result = { status => 1 };
     }
-
+    elsif($query eq "treaties")
+    {
+        print $self->world->print_treaties_table();
+        $result = { status => 1 };
+    }
     elsif($query =~ /^situation( (.*))?$/)
     {
         my $order = $2;
@@ -279,6 +290,13 @@ COMMANDS
         say $self->world->print_rebel_military_supports();  
         $result = { status => 1 };
     }
+    elsif($query =~ /save( (.*))?$/)
+    {
+        my $savefile = $2;
+        $savefile ||= $self->world->savefile;
+        say $self->world->dump_all($savefile);  
+        $result = { status => 1 };
+    }
     elsif($query =~ /^distance (.*)-(.*)$/)
     {
         my $n1 = $self->world->correct_nation_name($1);
@@ -477,7 +495,9 @@ sub orders
 sub interact
 {
     my $self = shift;
-    $self->world->pre_decisions_elaborations();
+    my $pre_decisions = shift;
+    $pre_decisions = 1 if(! defined $pre_decisions);
+    $self->world->pre_decisions_elaborations() if $pre_decisions;
     while($self->active)
     {
         my $result = undef;
