@@ -1,10 +1,11 @@
 package BalanceOfPower::Commands::ComTreaty;
-$BalanceOfPower::Commands::ComTreaty::VERSION = '0.140000';
+$BalanceOfPower::Commands::ComTreaty::VERSION = '0.150000';
 use Moo;
 
 use BalanceOfPower::Utils qw( prev_turn );
 
 extends 'BalanceOfPower::Commands::TargetRoute';
+with 'BalanceOfPower::Commands::Role::TreatiesUnderLimit';
 
 sub get_available_targets
 {
@@ -13,7 +14,7 @@ sub get_available_targets
     my $nation = $self->actor;
     @targets = grep {! $self->world->exists_treaty($nation, $_) } @targets;
     @targets = grep {! $self->world->diplomacy_status($nation, $_) ne 'HATE' } @targets;
-    return @targets;
+    return $self->nations_under_treaty_limit(@targets);
 }
 
 sub IA
