@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::Role::Command;
-$BalanceOfPower::Commands::Role::Command::VERSION = '0.140000';
+$BalanceOfPower::Commands::Role::Command::VERSION = '0.150000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -44,6 +44,10 @@ has army_limit => (
     is => 'ro',
     default => sub { {} }
 );
+has treaty_limit => (
+    is => 'ro',
+    default => 0
+);
 
 sub get_nation
 {
@@ -92,6 +96,13 @@ sub allowed
     {
         return 0;
     }
+    if($self->treaty_limit == 1)
+    {
+       if($self->world->get_treaties_for_nation($nation->name) >= $nation->treaty_limit)
+       {
+           return 0;
+       }
+    }
     return 1;
 }
 
