@@ -1,5 +1,5 @@
 package BalanceOfPower::Executive;
-$BalanceOfPower::Executive::VERSION = '0.140000';
+$BalanceOfPower::Executive::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -26,6 +26,7 @@ use BalanceOfPower::Commands::DeclareWar;
 use BalanceOfPower::Commands::AidInsurgents;
 use BalanceOfPower::Commands::DiplomaticPressure;
 use BalanceOfPower::Commands::MilitaryAid;
+use BalanceOfPower::Commands::Progress;
 
 has actor => (
     is => 'rw',
@@ -102,7 +103,8 @@ sub init
                                                                           "TREATY COM",
                                                              ],
                                                              world => $world,
-                                                             prestige_cost => TREATY_PRESTIGE_COST 
+                                                             prestige_cost => TREATY_PRESTIGE_COST,
+                                                             treaty_limit => 1,
                                                             );
     $self->commands->{"TREATY COM WITH"} = $command; 
     $command =
@@ -113,6 +115,7 @@ sub init
                                                                          ],
                                                              world => $world,
                                                              prestige_cost => TREATY_PRESTIGE_COST,
+                                                             treaty_limit => 1,
                                                             );
     $self->commands->{"TREATY NAG WITH"} = $command; 
     $command =
@@ -145,7 +148,12 @@ sub init
                                                     export_cost => MILITARY_AID_COST,
                                                   );
     $self->commands->{"MILITARY AID FOR"} = $command;
-   
+    $command =
+        BalanceOfPower::Commands::Progress->new( name => "PROGRESS",
+                                                    world => $world,
+                                                    domestic_cost => PROGRESS_COST,
+                                                  );
+    $self->commands->{"PROGRESS"} = $command;
 }
 
 
