@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.140000';
+$BalanceOfPower::Nation::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -75,6 +75,11 @@ has army => (
     is => 'rw'
 );
 
+has progress => (
+    default => 0,
+    is => 'rw'
+);
+
 has frozen_disorder => (
     default => 0,
     is => 'rw'
@@ -203,10 +208,13 @@ sub calculate_disorder
     return if($self->internal_disorder_status eq 'Civil war');
     return if($self->frozen_disorder);
 
+    my @ordered_best = $world->order_statistics(prev_turn($self->current_year), 'progress');
+    
     #Variables
     my $wd = $self->wealth / PRODUCTION_UNITS->[$self->size];
     my $d = $self->internal_disorder;
     my $g = $self->government_strength;
+    my $prg = $ordered_best[0] ? $ordered_best[0]->{'value'} - $self->progress : 0;
 
     #Constants
     my $wd_middle = 30;
@@ -216,11 +224,12 @@ sub calculate_disorder
     my $government_strength_divider = 40;
     my $random_factor_max = 15;
     
-    
     my $disorder = ( ($wd_middle - $wd) / $wd_divider ) +
                    ( $d / $disorder_divider           ) +
                    ( ($government_strength_minimum - $g) / $government_strength_divider ) +
-                   $world->random_around_zero($random_factor_max, 100, "Internal disorder random factor for " . $self->name);
+                   $world->random_around_zero($random_factor_max, 100, "Internal disorder random factor for " . $self->name) +
+                   $prg;
+
     $disorder = int ($disorder * 100) / 100;
     $self->register_event("DISORDER CHANGE: " . $disorder);
     $self->add_internal_disorder($disorder, $world);
@@ -491,6 +500,23 @@ sub add_army
 
 }
 
+sub grow
+{
+    my $self = shift;
+    return if($self->production_for_domestic < PROGRESS_COST);
+    my $new_progress = $self->progress + PROGRESS_INCREMENT;
+    $self->progress($new_progress);
+    $self->subtract_production('domestic', PROGRESS_COST);
+    $self->register_event("GROW. NEW PROGRESS: $new_progress");
+}
+
+sub treaty_limit
+{
+    my $self = shift;
+    my $progress_step = int($self->progress / TREATY_LIMIT_PROGRESS_STEP) + 1;
+    return $progress_step * TREATIES_FOR_PROGRESS_STEP;
+}   
+
 sub print_attributes
 {
     my $self = shift;
@@ -520,4 +546,35 @@ sub print
     return $out;
 }
 
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . 
+                join(";", $self->name, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->rebel_provinces, $self->current_year, $self->army, $self->progress) . "\n";
+    $self->dump_events($io, " " . $indent);
+}
+
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    my $nation_line = ( split /\n/, $data )[0];
+    $nation_line =~ s/^\s+//;
+    chomp $nation_line;
+    my ($name, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $rebel_provinces, $current_year, $army, $progress) = split ";", $nation_line;
+    $data =~ s/^.*?\n//;
+    my $events = $self->load_events($data);
+    return $self->new(name => $name, area => $area, size => $size,
+                      export_quote => $export_quote, government => $government, government_strength => $government_strength,
+                      internal_disorder => $internal_disorder, 
+                      production_for_domestic => $production_for_domestic, production_for_export => $production_for_export,
+                      prestige => $prestige, wealth => $wealth, debt => $debt,
+                      rebel_provinces => $rebel_provinces, army => $army,
+                      current_year => $current_year,
+                      progress => $progress,
+                      events => $events);
+}
+
 1;
