@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation::Role::IA;
-$BalanceOfPower::Nation::Role::IA::VERSION = '0.140000';
+$BalanceOfPower::Nation::Role::IA::VERSION = '0.150000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -9,7 +9,7 @@ use BalanceOfPower::Constants ':all';
 use BalanceOfPower::Utils qw( prev_turn );
 
 has executive => (
-    is => 'ro',
+    is => 'rw',
     handles => { decide => 'decide' }
     
 );
@@ -68,7 +68,8 @@ sub domestic_advisor
                           "BOOST PRODUCTION",
                           "TREATY NAG WITH",
                           "DIPLOMATIC PRESSURE ON",
-                          "MILITARY AID FOR");
+                          "MILITARY AID FOR",
+                          "PROGRESS");
 }
 
 sub economy_advisor
@@ -164,12 +165,24 @@ sub good_prey
         $war_points += -1;
     }
 
-    #WEALTH EVALUATION
+    #WEALTH EVALUATION/PROGRES EVALUATION
     my $wealth = $world->get_statistics_value(prev_turn($self->current_year), $self->name, 'wealth');
     my $enemy_wealth = $world->get_statistics_value(prev_turn($self->current_year), $enemy->name, 'wealth');
+    my $progress_delta = $enemy->progress - $self->progress;
     if($wealth && $enemy_wealth)
     {
-        $war_points += 1 if($enemy_wealth > $wealth);
+        if($enemy_wealth > $wealth)
+        {
+            $war_points += 1 
+        }
+        else
+        {
+            if($progress_delta > 0 && $progress_delta < MAX_AFFORDABLE_PROGRESS)
+            {
+                $war_points += 1 
+            }
+            
+        }
     }
     else
     {
