@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Friendship;
-$BalanceOfPower::Relations::Friendship::VERSION = '0.140000';
+$BalanceOfPower::Relations::Friendship::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -201,6 +201,22 @@ sub is_max_crisis
     my $self = shift;
     return $self->get_crisis_level() == CRISIS_MAX_FACTOR;
 }
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . join(";", $self->node1, $self->node2, $self->factor, $self->crisis_level) . "\n";
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    $data =~ s/^\s+//;
+    chomp $data;
+    my ($node1, $node2, $factor, $crisis_level) = split ";", $data;
+    return $self->new(node1 => $node1, node2 => $node2, factor => $factor, crisis_level => $crisis_level);
+}
 
 
 1;
