@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Influence;
-$BalanceOfPower::Relations::Influence::VERSION = '0.140000';
+$BalanceOfPower::Relations::Influence::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -112,7 +112,22 @@ sub actual_influence
         return 0;
     }
 }
-
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . join(";", $self->node1, $self->node2, $self->status, $self->next, $self->clock) . "\n";
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    $data =~ s/^\s+//;
+    chomp $data;
+    my ($node1, $node2, $status, $next, $clock) = split ";", $data;
+    return $self->new(node1 => $node1, node2 => $node2, status => $status, next => $next, clock => $clock);
+}
 
 
 1;
