@@ -1,9 +1,10 @@
 package BalanceOfPower::Relations::RelPack;
-$BalanceOfPower::Relations::RelPack::VERSION = '0.140000';
+$BalanceOfPower::Relations::RelPack::VERSION = '0.150000';
 use strict;
 use v5.10;
 
 use Moo;
+use Module::Load;
 
 has links => (
     is => 'rw',
@@ -380,5 +381,41 @@ sub near
     my $nodes = shift;
     return grep { $self->exists_link($node, $_) && $node ne $_ } @{$nodes};
 }
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    foreach my $l (@{$self->links})
+    {
+        $l->dump($io, $indent);
+    }
+}
+sub load_pack
+{
+    my $self = shift;
+    my $class = shift;
+    my $data = shift;
+    $data .= "EOF\n";
+    my @lines = split "\n", $data;
+    load $class;
+    my $rel_data = "";
+    foreach my $l (@lines)
+    {
+        if($l !~ /^\s/)
+        {
+            if($rel_data)
+            {
+                my $rel = $class->load($rel_data);
+                $self->add_link($rel);
+            }
+            $rel_data = $l . "\n";
+        }
+        else
+        {
+            $rel_data .= $l . "\n";
+        }
+    }
+}
 
 1;
