@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Role::Relation;
-$BalanceOfPower::Relations::Role::Relation::VERSION = '0.140000';
+$BalanceOfPower::Relations::Role::Relation::VERSION = '0.150000';
 use strict;
 use Moo::Role;
 
@@ -104,4 +104,20 @@ sub print
         }
     }
 }
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . $self->node1 . ";" . $self->node2 . "\n";
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    $data =~ s/^\s+//;
+    chomp $data;
+    my ($node1, $node2) = split ";", $data;
+    return $self->new(node1 => $node1, node2 => $node2);
+}
 1;
