@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::TradeRoute;
-$BalanceOfPower::Relations::TradeRoute::VERSION = '0.140000';
+$BalanceOfPower::Relations::TradeRoute::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -44,6 +44,24 @@ sub print
         return $from . " -[x" . $self->factor2 . "]-> " . $self->node1;
     }
 }
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . join(";", $self->node1, $self->node2, $self->factor1, $self->factor2) . "\n";
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    $data =~ s/^\s+//;
+    chomp $data;
+    my ($node1, $node2, $factor1, $factor2) = split ";", $data;
+    return $self->new(node1 => $node1, node2 => $node2, factor1 => $factor1, factor2 => $factor2);
+}
+
+
 
 
 
