@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Treaty;
-$BalanceOfPower::Relations::Treaty::VERSION = '0.140000';
+$BalanceOfPower::Relations::Treaty::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -39,5 +39,21 @@ sub short_tag
     }
 
 }
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . join(";", $self->node1, $self->node2, $self->type) . "\n";
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    $data =~ s/^\s+//;
+    chomp $data;
+    my ($node1, $node2, $type) = split ";", $data;
+    return $self->new(node1 => $node1, node2 => $node2, type => $type);
+}
 
 1;
