@@ -1,11 +1,11 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.140000';
+$BalanceOfPower::Role::Analyst::VERSION = '0.150000';
 use strict;
 use v5.10;
 use Moo::Role;
 use Term::ANSIColor;
 use BalanceOfPower::Constants ':all';
-use BalanceOfPower::Utils qw( prev_turn as_title as_title as_subtitle );
+use BalanceOfPower::Utils qw( prev_turn as_title as_title as_subtitle compare_turns);
 
 requires 'diplomacy_exists';
 requires 'get_borders';
@@ -49,7 +49,7 @@ sub print_nation_actual_situation
         $out .= $tr->print($nation) . "\n";
     }
     $out .= "\n";
-    my $allies_support_title = sprintf "%-35s %-35s", "TREATIES", "SUPPORTS";
+    my $allies_support_title = sprintf "%-35s %-35s", "TREATIES [" . $nation_obj->treaty_limit . "]" , "SUPPORTS";
     $allies_support_title .="\n";
     $allies_support_title .= sprintf "%-35s %-35s", "---", "---";
     $allies_support_title .="\n";
@@ -256,12 +256,48 @@ sub print_war_history
 {
     my $self = shift;
     my $out .= as_title("WAR HISTORY\n\n");
+    my %wars;
+    my @war_names;
     foreach my $w (@{$self->memorial})
     {
-        $out .= $w->print_history;
+        if(exists $wars{$w->war_id})
+        {
+           $wars{$w->war_id} .=  $w->print_history . "\n";
+        }
+        else
+        {
+           $wars{$w->war_id} =  $w->print_history . "\n";
+           push @war_names, { name => $w->war_id,
+                              start => $w->start_date  };
+        }
+    }
+    sub comp
+    {
+        compare_turns($a->{start}, $b->{start});
+    }
+    for(sort comp @war_names)
+    {
+        $out .= "### WAR " . $_->{name} . "\n";
+        $out .= $wars{$_->{name}};
+    }
+    return $out;
+}
+sub print_treaties_table
+{
+    my $self = shift;
+    my $out = sprintf "%-20s %-6s %-5s %-5s %-5s", "Nation", "LIMIT", "ALL", "NAG", "COM";
+    $out .= "\n";
+    my @nations = @{$self->nation_names};
+    for(@nations)
+    {
+        my $n = $_;
+        my $limit = $self->get_nation($n)->treaty_limit;
+        my $alls = $self->get_treaties_for_nation_by_type($n, 'alliance');
+        my $coms = $self->get_treaties_for_nation_by_type($n, 'commercial');
+        my $nags = $self->get_treaties_for_nation_by_type($n, 'no aggression');
+        $out .= sprintf "%-20s %-6s %-5s %-5s %-5s", $n, $limit, $alls, $nags, $coms;
         $out .= "\n";
     }
     return $out;
-
 }
 1;
