@@ -1,10 +1,11 @@
 package BalanceOfPower::Role::Historian;
-$BalanceOfPower::Role::Historian::VERSION = '0.140000';
+$BalanceOfPower::Role::Historian::VERSION = '0.150000';
 use v5.10;
 use strict;
 use Moo::Role;
 use Term::ANSIColor;
 use List::Util qw( min max );
+use Data::Dumper;
 
 use BalanceOfPower::Utils qw( get_year_turns as_title from_to_turns );
 use BalanceOfPower::Constants ':all';
@@ -107,18 +108,20 @@ sub plot_nation_factor
     my $graph_height = 12;
 
     my @data = ();
+    my $valid = 0;
     foreach my $t (from_to_turns($first_turn, $last_turn))
     {
         if(defined $self->get_statistics_value($t, $nation, $factor))
         {
             push @data, $self->get_statistics_value($t, $nation, $factor);
+            $valid = 1;
         }
         else
         {
             push @data, undef;
         }
     }
-    return "" if(@data == 0);
+    return "" if(! $valid);
     my $min = min @data;
     my $max = max @data;
     my $step = ($max - $min) / $graph_height;
@@ -160,11 +163,11 @@ sub print_nation_statistics_header
 {
     if(DEBT_ALLOWED)
     {
-        return "Size\tProd.\tWealth\tW/D\tGrowth\tDebt\tDisor.\tArmy\tPstg.";
+        return "Size\tProd.\tWealth\tW/D\tGrowth\tDebt\tDisor.\tArmy\tProg.\tPstg.";
     }
     else
     {
-        return "Size\tProd.\tWealth\tW/D\tGrowth\tDisor.\tArmy\tPstg.";
+        return "Size\tProd.\tWealth\tW/D\tGrowth\tDisor.\tArmy\tProg.\tPstg.";
     }
 }
 sub print_nation_statistics_line
@@ -189,6 +192,7 @@ sub print_nation_statistics_line
     }
     $out .= $self->get_statistics_value($y, $nation, 'internal disorder') . "\t";
     $out .= $self->get_statistics_value($y, $nation, 'army') . "\t";
+    $out .= $self->get_statistics_value($y, $nation, 'progress') . "\t";
     $out .= $self->get_statistics_value($y, $nation, 'prestige') . "\t";
     return $out;
 }
@@ -349,6 +353,24 @@ sub print_defcon_statistics
     return $out;
 }
 
+sub dump_statistics
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    my $dump = Data::Dumper->new([$self->statistics]);
+    $dump->Indent(0);
+    print {$io} $indent . $dump->Dump . "\n";
+}
+sub load_statistics
+{
+    my $self = shift;
+    my $data = shift;
+    my $VAR1;
+    eval ( $data );
+    $self->statistics($VAR1);
+}
+
 
 1;
 
