@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Reporter;
-$BalanceOfPower::Role::Reporter::VERSION = '0.140000';
+$BalanceOfPower::Role::Reporter::VERSION = '0.150000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -100,6 +100,51 @@ sub _print_turn_events
     }
     return $out; 
 }
+sub dump_events
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    sub sort_start
+    {
+        return 0 if($a eq $b);
+        return -1 if($a eq 'START');
+        return 1 if($b eq 'START');
+        return 1 if($a gt $b);
+        return -1 if($b gt $a);
+    }
+    foreach my $y (sort sort_start keys %{$self->events})
+    {
+        print {$io} $indent . "### $y\n";
+        foreach my $e (@{$self->events->{$y}})
+        {
+            print {$io} $indent . $e . "\n";
+        }
+    }
+}
+sub load_events
+{
+    my $self = shift;
+    my $data = shift;
+    my @lines = split "\n", $data;
+    my $year = "";
+    my %events;
+    foreach my $l (@lines)
+    {
+        $l =~ s/^\s//;
+        chomp $l;
+        if($l =~ /### (.*)$/)
+        {
+            $year = $1;
+            $events{$year} = [];
+        }
+        else
+        {
+            push @{$events{$year}}, $l;
+        }
+    }
+    return \%events;
+}
 
 
 1;
