@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Warlord;
-$BalanceOfPower::Role::Warlord::VERSION = '0.140000';
+$BalanceOfPower::Role::Warlord::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -44,7 +44,7 @@ has wars => (
 );
 
 has memorial => (
-    is => 'ro',
+    is => 'rw',
     default => sub { [] }
 );
 
@@ -315,12 +315,14 @@ sub war_starting_report
     my $node1 = $war->node1;
     my $node2 = $war->node2;
     $war->register_event("Starting army for " . $node1 . ": " . $self->get_nation($node1)->army);
+    $war->register_event("Progress of " . $node1 . ": " . $self->get_nation($node1)->progress);
     my $sup1 = $self->supported($node1);
     if($sup1)
     {
         $war->register_event("$node1 is supported by " . $sup1->node1 . ": " . $sup1->army);
     }
     $war->register_event("Starting army for " . $node2 . ": " . $self->get_nation($node2)->army);
+    $war->register_event("Progress of " . $node2 . ": " . $self->get_nation($node2)->progress);
     my $sup2 = $self->supported($node2);
     if($sup2)
     {
@@ -402,10 +404,24 @@ sub fight_wars
         my $attacker_damage = 0;
         my $defender_damage = 0;
         my $counter = $attack < $defence ? $attack : $defence;
+        my $progress_delta = $attacker->progress - $defender->progress;
+        my $attacker_progress_bonus;
+        my $defender_progress_bonus;
+        if($progress_delta > 0)
+        {
+            $attacker_progress_bonus = $progress_delta * PROGRESS_BATTLE_FACTOR;
+            $defender_progress_bonus = 0;
+        }
+        else
+        {
+            $attacker_progress_bonus = 0;
+            $defender_progress_bonus = $progress_delta * PROGRESS_BATTLE_FACTOR * -1;
+        }
         for(my $i = 0; $i < $counter; $i++)
         {
-            my $att = $self->random(1, 6, "War risiko: throw for attacker " . $attacker->name);
-            my $def = $self->random(1, 6, "War risiko: throw for defender " . $defender->name);
+            my $att = int(($self->random(1, 60, "War risiko: throw for attacker " . $attacker->name) + $attacker_progress_bonus) / 10) + 1;
+            my $def = int(($self->random(1, 60, "War risiko: throw for defender " . $defender->name) + $defender_progress_bonus) / 10) + 1;
+
             if($att > $def)
             {
                 $defender_damage++;
@@ -546,6 +562,44 @@ sub print_wars
     }
     return $out;
 }
+sub dump_memorial
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift;
+    foreach my $w (@{$self->memorial})
+    {
+        print {$io} $w->dump($io, $indent);
+    }
+}
+sub load_memorial
+{
+    my $self = shift;
+    my $data = shift;
+    my $war_data = "";
+    my @memorial;
+    my @lines = split "\n", $data;
+    foreach my $l (@lines)
+    {
+        if($l !~ /^\s/)
+        {
+            if($war_data)
+            {
+                push @memorial, BalanceOfPower::Relations::War->load($war_data);
+                $war_data = $l . "\n";
+            }
+            else
+            {
+                $war_data = $l . "\n";
+            }
+        }
+        else
+        {
+            $war_data .= $l . "\n";
+        }
+    }
+    return \@memorial;
+}
 
 
 1;
