@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.140000';
+$BalanceOfPower::World::VERSION = '0.150000';
 use strict;
 use v5.10;
 
@@ -70,6 +70,10 @@ has dice => (
                  dice_log => 'log_active'
                }
 );
+has savefile => (
+    is => 'rw',
+    default => ""
+);
 
 
 with 'BalanceOfPower::Role::Player';
@@ -88,6 +92,11 @@ sub get_nation
 {
     my $self = shift;
     my $nation = shift;
+    if(! $nation)
+    {
+        say "Nation is undef";
+        return undef;
+    }
     my @nations = grep { $_->name eq $nation } @{$self->nations};
     if(@nations > 0)
     {
@@ -95,6 +104,7 @@ sub get_nation
     }
     else
     {
+        say "Cannot found $nation";
         return undef;
     }
 }
@@ -436,19 +446,32 @@ sub calculate_prestige
     $prestige += @supported;
     my @influenced = $self->has_influence($nation_name);
     $prestige += @influenced * INFLUENCE_PRESTIGE_BONUS;
-    my @ordered_best = $self->order_statistics(prev_turn($nation->current_year), 'w/d');
     my $bonus = 0;
-    if(@ordered_best >= BEST_WEALTH_FOR_PRESTIGE)
+    my @ordered_best_w = $self->order_statistics(prev_turn($nation->current_year), 'w/d');
+    if(@ordered_best_w >= BEST_WEALTH_FOR_PRESTIGE)
     {
         for(my $i = 0; $i < BEST_WEALTH_FOR_PRESTIGE; $i++)
         {
-            if($ordered_best[$i]->{nation} eq $nation_name)
+            if($ordered_best_w[$i]->{nation} eq $nation_name)
             {
-                $bonus = BEST_WEALTH_FOR_PRESTIGE_BONUS;
+                $bonus += BEST_WEALTH_FOR_PRESTIGE_BONUS;
                 $self->broadcast_event("ONE OF THE FIRST " . BEST_WEALTH_FOR_PRESTIGE . " NATIONS FOR WEALTH WAS " . $nation_name, $nation_name);
             }
         }
     }
+    my @ordered_best_p = $self->order_statistics(prev_turn($nation->current_year), 'progress');
+    if(@ordered_best_p >= BEST_PROGRESS_FOR_PRESTIGE)
+    {
+        for(my $i = 0; $i < BEST_PROGRESS_FOR_PRESTIGE; $i++)
+        {
+            if($ordered_best_p[$i]->{nation} eq $nation_name)
+            {
+                $bonus += BEST_PROGRESS_FOR_PRESTIGE_BONUS;
+                $self->broadcast_event("ONE OF THE FIRST " . BEST_PROGRESS_FOR_PRESTIGE . " NATIONS FOR PROGRESS WAS " . $nation_name, $nation_name);
+            }
+        }
+    }
+   
     $prestige += $bonus;
     my @wins = $nation->get_events("WAR BETWEEN .* AND .* WON BY ". $nation_name, prev_turn($nation->current_year));
     if(@wins > 0)
@@ -584,6 +607,12 @@ sub execute_decisions
             my $nation2 = $self->get_nation($2);
             $self->military_aid($nation1, $nation2);
         }
+        elsif($d =~ /^(.*): PROGRESS$/)
+        {
+            my $nation =  $self->get_nation($1);
+            $nation->grow();
+            $self->broadcast_event("INVESTMENT IN PROGRESS FOR " . $nation->name, $nation->name);
+        }
     }
     $self->manage_route_adding(@route_adders);
 }
@@ -822,6 +851,12 @@ sub stipulate_treaty
         $self->broadcast_event("TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE OF HATE", $nation1->name, $nation2->name);
         return;
     }
+    if($self->get_treaties_for_nation($nation1->name) >= $nation1->treaty_limit ||
+       $self->get_treaties_for_nation($nation2->name) >= $nation2->treaty_limit)
+    {
+        $self->broadcast_event("TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE ONE NATION HAS ALREADY REACHED MAXIMUM ALLOWED TREATIES", $nation1->name, $nation2->name);
+        return;
+    }
     if($nation1->prestige >= TREATY_PRESTIGE_COST)
     {
         if($type eq 'COM')
@@ -893,7 +928,7 @@ sub collect_events
        {
             $self->register_event($n->name . ": ". $c);
        }
-       
+       $self->set_statistics_value($n, 'progress', $n->progress);
    }
 }
 
@@ -907,6 +942,170 @@ sub build_commands
     return $commands;
 }
 
+sub dump
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+    print {$io} $indent . join(";", $self->name, $self->first_year, $self->current_year, $self->player, $self->player_nation) . "\n";
+    $self->dump_events($io, " " . $indent);
+}
+sub load
+{
+    my $self = shift;
+    my $data = shift;
+    my $world_line = ( split /\n/, $data )[0];
+    $world_line =~ s/^\s+//;
+    chomp $world_line;
+    my ($name, $first_year, $current_year, $player, $player_nation) =
+        split ";", $world_line;
+    $data =~ s/^.*?\n//;
+    my $events = $self->load_events($data);
+    return BalanceOfPower::World->new(name => $name, 
+                                      first_year => $first_year, current_year => $current_year,
+                                      player => $player, player_nation => $player_nation,
+                                      events => $events);
+}
+
+sub load_nations
+{
+    my $self = shift;
+    my $data = shift;
+    $data .= "EOF\n";
+    my $nation_data = "";
+    foreach my $l (split "\n", $data)
+    {
+
+        if($l !~ /^\s/)
+        {
+            if($nation_data)
+            {
+                my $nation = BalanceOfPower::Nation->load($nation_data);
+                my $executive = BalanceOfPower::Executive->new( actor => $nation->name );
+                $executive->init($self);
+                $nation->executive($executive);
+                push @{$self->nations}, $nation;
+                push @{$self->nation_names}, $nation->name;
+            }
+            $nation_data = $l . "\n";
+        }
+        else
+        {
+            $nation_data .= $l . "\n";
+        }
+    }
+}
+
+sub dump_all
+{
+    my $self = shift;
+    my $file = shift;
+    return "No file provided" if ! $file;
+    open(my $io, "> $file");
+    $self->dump($io);
+    print {$io} "### NATIONS\n";
+    for(@{$self->nations})
+    {
+        $_->dump($io);
+    }
+    print {$io} "### DIPLOMATIC RELATIONS\n";
+    $self->diplomatic_relations->dump($io);
+    print {$io} "### TREATIES\n";
+    $self->treaties->dump($io);
+    print {$io} "### BORDERS\n";
+    $self->borders->dump($io);
+    print {$io} "### TRADEROUTES\n";
+    $self->trade_routes->dump($io);
+    print {$io} "### INFLUENCES\n";
+    $self->influences->dump($io);
+    print {$io} "### SUPPORTS\n";
+    $self->military_supports->dump($io);
+    print {$io} "### REBEL SUPPORTS\n";
+    $self->rebel_military_supports->dump($io);
+    print {$io} "### WARS\n";
+    $self->wars->dump($io);
+    print {$io} "### MEMORIAL\n";
+    $self->dump_memorial($io);
+    print {$io} "### STATISTICS\n";
+    $self->dump_statistics($io);
+    print {$io} "### EOF\n";
+    close($io);
+    return "World saved to $file";
+}   
+
+sub load_world
+{
+    my $self = shift;
+    my $file = shift;
+    open(my $dump, "<", $file) or die "Problems opening $file: $!";
+    my $world;
+    my $target = "WORLD";
+    my $data = "";
+    for(<$dump>)
+    {
+        my $line = $_;
+        if($line =~ /^### (.*)$/)
+        {
+            my $next = $1;
+            if($target eq 'WORLD')
+            {
+                $world = $self->load($data);
+            }
+            elsif($target eq 'NATIONS')
+            {
+                $world->load_nations($data);
+            }
+            elsif($target eq 'DIPLOMATIC RELATIONS')
+            {
+                $world->diplomatic_relations->load_pack("BalanceOfPower::Relations::Friendship", $data);
+            }
+            elsif($target eq 'TREATIES')
+            {
+                $world->treaties->load_pack("BalanceOfPower::Relations::Treaty", $data);
+            }
+            elsif($target eq 'BORDERS')
+            {
+                $world->borders->load_pack("BalanceOfPower::Relations::Border", $data);
+            }
+            elsif($target eq 'TRADEROUTES')
+            {
+                $world->trade_routes->load_pack("BalanceOfPower::Relations::TradeRoute", $data);
+            }
+            elsif($target eq 'INFLUENCES')
+            {
+                $world->influences->load_pack("BalanceOfPower::Relations::Influence", $data);
+            }
+            elsif($target eq 'SUPPORTS')
+            {
+                $world->military_supports->load_pack("BalanceOfPower::Relations::MilitarySupport", $data);
+            }
+            elsif($target eq 'REBEL SUPPORTS')
+            {
+                $world->rebel_military_supports->load_pack("BalanceOfPower::Relations::MilitarySupport", $data);
+            }
+            elsif($target eq 'WARS')
+            {
+                $world->wars->load_pack("BalanceOfPower::Relations::War", $data);
+            }
+            elsif($target eq 'MEMORIAL')
+            {
+                $world->memorial($world->load_memorial($data));
+            }
+            elsif($target eq 'STATISTICS')
+            {
+                $world->load_statistics($data);
+            }
+            $data = "";
+            $target = $next;
+        }
+        else
+        {
+            $data .= $line;
+        }
+    }
+    close($dump);
+    return $world;
+}
 
 
 1;
